# Enable HMM filter

One can remove `--nohmm` in the command to enable HMM filter. However, HMM filter may also filter some important structures. One should read [the original paper](https://doi.org/10.1039/C9CP05091D) and carefully adjust HMM parameters.

HMM filter should not be used to generate the special result by time step.